__version__ = '1.0.3'

import logging
import sys

from ma5_expert.system import logger

logger.init(LoggerStream = sys.stdout)
log = logging.getLogger("ma5_expert")
log.setLevel(logging.INFO)

from ma5_expert import cutflow

__all__ = cutflow.__all__



Red = "\x1b[31m"
End = "\x1b[0m"


class InvalidInput(Exception):
    """Invalid Domain Exception"""

    def __init__(self, message="Invalid Input!"):
        super(InvalidInput, self).__init__(Red + message + End)
